﻿/*
 * 共通工具类
 */

/**
 * @description 字符串替换所有字符
 * @param {String} target 需替换目标字符串
 * @param {String} replacement 替换用字符串
 * @return {String}
 **/
String.prototype.ReplaceAll = function(target, replacement) {
	return this.split(target).join(replacement);
};
/**
 * @description 格式化字符串
 * @param {String} format 需格式化字符串
 * @return {String}
 **/
String.prototype.Format = function() {
	var args = arguments;
	return this.replace(/\{(\d+)\}/g, function(m, i) {
		return args[Number(i) + 1];
	});
};

/**
 * @description 字符串过滤
 * @param {String} strInterval=[s|n|h|d|w|q|m|y] 计算单位 q 季度,w 7天, s 秒 ，n 分钟，h 小时……
 * @param {Number} replacement 相加的值
 * @return {Date}
 **/
var stringFilter = function(str) {
		str = str.replaceAll(".", "!DIAN!");
		str = str.replaceAll(":", "!MAOHAO!");
		str = str.replaceAll("/", "!XIEGANG!");
		str = str.replaceAll("'", "!DANYINHAO!");
		str = str.replaceAll("<", "!ZUOJIANKH!");
		str = str.replaceAll(">", "!YOUJIANKH!");
		return str;
	}

/**
 * @description 日期格式化
 * @param {String} formatStr=[yyyy-MM-dd HH:mm:ss|yyyy-MM-dd] 日期格式 可到秒
 * @return {String}
 */
Date.prototype.Format = function(formatStr) {
	var str = formatStr;
	var Week = ['日', '一', '二', '三', '四', '五', '六'];
	str = str.replace(/yyyy|YYYY/, this.getFullYear());
	str = str.replace(/yy|YY/, (this.getYear() % 100) > 9 ? (this.getYear() % 100).toString() : '0' + (this.getYear() % 100));
	str = str.replace(/MM/, (this.getMonth() + 1) > 9 ? (this.getMonth() + 1).toString() : '0' + (this.getMonth() + 1));
	str = str.replace(/M/g, this.getMonth() + 1);
	str = str.replace(/w|W/g, Week[this.getDay()]);
	str = str.replace(/dd|DD/, this.getDate() > 9 ? this.getDate().toString() : '0' + this.getDate());
	str = str.replace(/d|D/g, this.getDate());
	str = str.replace(/hh|HH/, this.getHours() > 9 ? this.getHours().toString() : '0' + this.getHours());
	str = str.replace(/h|H/g, this.getHours());
	str = str.replace(/mm/, this.getMinutes() > 9 ? this.getMinutes().toString() : '0' + this.getMinutes());
	str = str.replace(/m/g, this.getMinutes());
	str = str.replace(/ss|SS/, this.getSeconds() > 9 ? this.getSeconds().toString() : '0' + this.getSeconds());
	str = str.replace(/s|S/g, this.getSeconds());
	return str;
}

/**
 * @description 日期计算
 * @param {String} strInterval=[s|n|h|d|w|q|m|y] 计算单位 q 季度,w 7天, s 秒 ，n 分钟，h 小时……
 * @param {Number} replacement 相加的值
 * @return {Date}
 **/
Date.prototype.DateAdd = function(strInterval, numbers) {
	var dtTmp = this;
	switch (strInterval) {
		case 's':
			return new Date(Date.parse(dtTmp) + (1000 * numbers));
		case 'n':
			return new Date(Date.parse(dtTmp) + (60000 * numbers));
		case 'h':
			return new Date(Date.parse(dtTmp) + (3600000 * numbers));
		case 'd':
			return new Date(Date.parse(dtTmp) + (86400000 * numbers));
		case 'w':
			return new Date(Date.parse(dtTmp) + ((86400000 * 7) * numbers));
		case 'q':
			return new Date(dtTmp.getFullYear(), (dtTmp.getMonth()) + numbers * 3, dtTmp.getDate(), dtTmp.getHours(), dtTmp.getMinutes(), dtTmp.getSeconds());
		case 'm':
			return new Date(dtTmp.getFullYear(), (dtTmp.getMonth()) + numbers, dtTmp.getDate(), dtTmp.getHours(), dtTmp.getMinutes(), dtTmp.getSeconds());
		case 'y':
			return new Date((dtTmp.getFullYear() + numbers), dtTmp.getMonth(), dtTmp.getDate(), dtTmp.getHours(), dtTmp.getMinutes(), dtTmp.getSeconds());
	}
}

/**
 * @description Json Time 转为日期类型
 * @param {String} jsontime Json Time
 * @return {Date}
 **/
var parseJsonTime = function(jsontime) {
	if (jsontime == "" || jsontime == "无") return null;
	if (jsontime == null) return null;
	var regEx = /(\\*\/Date\(.*?\)\\*\/)/g;
	var resultDate;
	var regExDate = function(str, p1, p2, offset, s) {
		str = str.replace('"', '');
		var date = str;
		if (/\/Date(.*)\//.test(str)) {
			str = str.match(/Date\((.*?)\)/)[1];
			date = new Date(parseInt(str));
		} else {
			var matches = str.split(/[-,:,T,Z]/);
			matches[1] = (parseInt(matches[1], 0) - 1).toString();
			date = "new Date(Date.UTC(" + matches.join(",") + "))";
		}
		resultDate = date;
	};
	jsontime.replace(regEx, regExDate);
	return resultDate;
};

/**
 * @description Json Time 转为日期字符串
 * @param {String} jsontime Json Time
 * @return {String}
 **/
var JsonTimetostring = function(jsontime) {
	if (jsontime == "" || jsontime == "无") return jsontime;
	if (jsontime == null) return "";
	var regEx = /(\\*\/Date\(.*?\)\\*\/)/g;
	var regExDate = function(str, p1, p2, offset, s) {
		str = str.replace('"', '');
		var date = str;
		if (/\/Date(.*)\//.test(str)) {
			str = str.match(/Date\((.*?)\)/)[1];
			date = new Date(parseInt(str));
		} else {
			var matches = str.split(/[-,:,T,Z]/);
			matches[1] = (parseInt(matches[1], 0) - 1).toString();
			date = "new Date(Date.UTC(" + matches.join(",") + "))";
		}
		return formatDateTime(date);
	};
	return jsontime.replace(regEx, regExDate);
};

/**
 * @description 时间类型格式化为中文
 * @param {Date} date
 * @return {String}
 **/
function formatDateTime(date) {
	if (date.getFullYear() >= 9999) {
		return "";
	}
	var dateStr = date.getFullYear() + '年';
	dateStr += (date.getMonth() + 1) + '月';
	dateStr += date.getDate() + '日 ';
	dateStr += pad(date.getHours(), 2) + ':';
	dateStr += pad(date.getMinutes(), 2) + ':';
	dateStr += pad(date.getSeconds(), 2);
	// 补位
	function pad(num, n) {
		return (Math.pow(10, n) + num + '').substr(1);
	}
	return dateStr;
}

/**
 * @description 日期类型转换为JSON类型
 * @param {Date} date
 * @return {String}
 **/
function date2JsonStr(date) {
	return "/Date(" + date.getTime() + "+0800)/";
}

/**
 * @description 字符串转换为日期
 * @param {String} str
 * @return {Date}
 **/
function str2Date(str) {
	return new Date(Date.parse(str.replace(/-/g, "/")));
}


/**
 * @description 判断集合对象是否为非空集合
 * @param {Object} obj
 * @return {Boolean}
 **/
function IsNotNullOrEmptyList(obj) {
	if (obj == null)
		return false;
	return typeof(obj) != 'undefined' && obj.length > 0
};

/**
 * @description 判断变量（非数据、集合）是否不为空
 * @param {Object} obj
 * @return {Boolean}
 **/
function IsNotNullOrUndefined(obj) {
	if (obj == null)
		return false;
	return typeof(obj) != 'undefined'
};

/**
 * @description 检查是否为数字字符串
 * @param {Boolean} isCanNull = [true|false] 指定对象是否可为空
 * @return {Boolean}
 */
String.prototype.IsNum = function(isCanNull) {
	if (this.length == 0)
		return isCanNull;
	if (this == "0")
		return true;
	var patrn = /^[1-9]\d*$/;
	if (!patrn.exec(this)) return false
	return true;
}

/**
 * @description 检查是否在指定长度内的数字字符串
 * @param {Boolean} isCanNull = [true|false] 指定对象是否可为空
 * @param {Number} length   长度
 * @return {Boolean}
 */
String.prototype.IsNumLimitLength = function(isCanNull, length) {
		if (this.length == 0)
			return isCanNull;
		if (this.length > length)
			return false;
		if (this == "0")
			return true;
		var patrn = /^[1-9]\d*$/;
		if (!patrn.exec(this)) return false
		return true;
	}

/**
 * @description 检查是否为正整数
 * @return {Boolean}
 */
String.prototype.IsUnsignedInteger = function() {
		var p = /^\+?[1-9][0-9]*$/;
		return p.test(this);
	}

/**
 * @description 检查是否为小数点后两位正浮点
 * @return {Boolean}
 */
String.prototype.IsFloatInteger = function() {
	var p = /(^[1-9]\d*(\.\d{1,2})?$)|(^0\.\d?[1-9]$)/;
	return p.test(this);
}

/**
 * @description 深复制对象
 * @param  {Object}
 * @return {Object} 复制产生的新对象
 */
function clone3(obj) {
	function Clone() {}
	Clone.prototype = obj;
	var o = new Clone();
	for (var a in o) {
		if (typeof o[a] == "object") {
			o[a] = clone3(o[a]);
		}
	}
	return o;
}

/*//数组排序 --中英文都可
function sortLetter(itemA, itemB) {
    var _itemA = itemA.Name;
    var _array = [itemA.Name, itemB.Name].sort(function (a1, a2) { return a1.localeCompare(a2); });
    if (_array[0] == _itemA) { return -1; } else { return 1; }
}
*/

/**
 * @description 读取对象属性为字符串
 * @param  {Object}
 * @return {String} 对象属性集合字符串
 */
function ObjectToString(OppObj) {
	var rst = "";
	var copy = OppObj;
	var aPrototype = new Object()

	for (var member in OppObj) {
		{
			rst += member + ":" + copy[member] + ',';
		}
	}
	return rst.substring(0, rst.length - 1);
}
